export interface Loader {
    getName(): string;
    load(options: any): Promise<any>;
}
/**
 * Config class.
 *
 * @constructor
 */
export declare class Config {
    private _store;
    private loaders;
    /**
     * Constructor
     *
     * @param {object} [object] - Optional object to merge into the configuration at construction time.
     */
    constructor(object?: any);
    /**
     * Add a loader.
     *
     * @param {Loader} loader
     * @returns {Config}
     */
    registerLoader(loader: Loader): this;
    /**
     * Get a loader by name.
     *
     * @param {string} name
     * @returns {Loader}
     */
    private getLoader(name);
    /**
     * Load data using loader configurations.
     *
     * @param {any[]} configs
     * @returns {Promise<void>}
     */
    load(configs: any[]): Promise<void>;
    /**
     * Get a value by path.
     *
     * Inspired by nconf.
     *
     * @param {String} [path]
     * @return {Object}
     * @see {@link https://github.com/indexzero/nconf/blob/af0e9fb7e7a36d51e6d43764b7954d706eac85cd/lib/nconf/stores/memory.js#L37}
     */
    get(path?: string): any;
    /**
     * Set a value by path.
     *
     * @param {string} path
     * @param {any} value
     * @return {Config} this
     */
    set(path: string, value: any): this;
    /**
     * Merge an object into the configuration.
     *
     * @param {Object} [object]
     * @returns {Config}
     */
    merge(object?: any): this;
}
